summaryrefslogtreecommitdiffstats
path: root/sync/internal_api/public/sync_manager.h
diff options
context:
space:
mode:
authordcheng@chromium.org <dcheng@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-08-28 03:17:58 +0000
committerdcheng@chromium.org <dcheng@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-08-28 03:17:58 +0000
commita329cb82a4627bea79c0db5dabe09698ad83c27e (patch)
treeca12b48cef0de11d3058bee683e082281f5061ec /sync/internal_api/public/sync_manager.h
parent3c6babd32ae5b7e8125ac16ee4e686654bcf59d6 (diff)
downloadchromium_src-a329cb82a4627bea79c0db5dabe09698ad83c27e.zip
chromium_src-a329cb82a4627bea79c0db5dabe09698ad83c27e.tar.gz
chromium_src-a329cb82a4627bea79c0db5dabe09698ad83c27e.tar.bz2
Rename SyncNotifier->Invalidator and SyncNotifierObserver->InvalidationHandler.
This makes the naming more consistent with how the various classes and interfaces are used, since they are not sync-specific anymore. BUG=none TBR=sky Review URL: https://chromiumcodereview.appspot.com/10875064 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@153619 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'sync/internal_api/public/sync_manager.h')
-rw-r--r--sync/internal_api/public/sync_manager.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/sync/internal_api/public/sync_manager.h b/sync/internal_api/public/sync_manager.h
index 5facc1e..dfd3cb3 100644
--- a/sync/internal_api/public/sync_manager.h
+++ b/sync/internal_api/public/sync_manager.h
@@ -38,11 +38,11 @@ struct Experiments;
class ExtensionsActivityMonitor;
class HttpPostProviderFactory;
class InternalComponentsFactory;
+class InvalidationHandler;
+class Invalidator;
class JsBackend;
class JsEventHandler;
class SyncEncryptionHandler;
-class SyncNotifier;
-class SyncNotifierObserver;
class SyncScheduler;
class UnrecoverableErrorHandler;
struct UserShare;
@@ -290,7 +290,7 @@ class SyncManager {
// |model_safe_worker| ownership is given to the SyncManager.
// |user_agent| is a 7-bit ASCII string suitable for use as the User-Agent
// HTTP header. Used internally when collecting stats to classify clients.
- // |sync_notifier| is owned and used to listen for notifications.
+ // |invalidator| is owned and used to listen for invalidations.
// |restored_key_for_bootstrapping| is the key used to boostrap the
// cryptographer
// |keystore_encryption_enabled| determines whether we enable the keystore
@@ -311,7 +311,7 @@ class SyncManager {
ExtensionsActivityMonitor* extensions_activity_monitor,
ChangeDelegate* change_delegate,
const SyncCredentials& credentials,
- scoped_ptr<SyncNotifier> sync_notifier,
+ scoped_ptr<Invalidator> invalidator,
const std::string& restored_key_for_bootstrapping,
const std::string& restored_keystore_key_for_bootstrapping,
scoped_ptr<InternalComponentsFactory> internal_components_factory,
@@ -342,18 +342,18 @@ class SyncManager {
virtual void UpdateEnabledTypes(
const ModelTypeSet& enabled_types) = 0;
// Forwards to the underlying notifier (see comments in sync_notifier.h).
virtual void RegisterInvalidationHandler(
- SyncNotifierObserver* handler) = 0;
+ InvalidationHandler* handler) = 0;
- // Forwards to the underlying notifier (see comments in sync_notifier.h).
+ // Forwards to the underlying notifier (see comments in invalidator.h).
virtual void UpdateRegisteredInvalidationIds(
- SyncNotifierObserver* handler,
+ InvalidationHandler* handler,
const ObjectIdSet& ids) = 0;
// Forwards to the underlying notifier (see comments in sync_notifier.h).
virtual void UnregisterInvalidationHandler(
- SyncNotifierObserver* handler) = 0;
+ InvalidationHandler* handler) = 0;
// Put the syncer in normal mode ready to perform nudges and polls.
virtual void StartSyncingNormally(
@@ -342,18 +342,18 @@ class SyncManager {
virtual void UpdateEnabledTypes(
const ModelTypeSet& enabled_types) = 0;
- // Forwards to the underlying notifier (see comments in sync_notifier.h).
+ // Forwards to the underlying invalidator (see comments in invalidator.h).
virtual void RegisterInvalidationHandler(
@@ -342,18 +342,18 @@ class SyncManager {
const ObjectIdSet& ids) = 0;
- // Forwards to the underlying notifier (see comments in sync_notifier.h).
+ // Forwards to the underlying notifier (see comments in invalidator.h).
virtual void UnregisterInvalidationHandler(